# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/image.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    classification_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/image.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\nImageProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n-google/cloud/automl_v1beta1/proto/image.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x36google/cloud/automl_v1beta1/proto/classification.proto\x1a\x1fgoogle/protobuf/timestamp.proto"r\n"ImageClassificationDatasetMetadata\x12L\n\x13\x63lassification_type\x18\x01 \x01(\x0e\x32/.google.cloud.automl.v1beta1.ClassificationType"%\n#ImageObjectDetectionDatasetMetadata"\x8c\x01\n ImageClassificationModelMetadata\x12\x15\n\rbase_model_id\x18\x01 \x01(\t\x12\x14\n\x0ctrain_budget\x18\x02 \x01(\x03\x12\x12\n\ntrain_cost\x18\x03 \x01(\x03\x12\x13\n\x0bstop_reason\x18\x05 \x01(\t\x12\x12\n\nmodel_type\x18\x07 \x01(\t"]\n!ImageObjectDetectionModelMetadata\x12\x12\n\nmodel_type\x18\x01 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x03\x12\x10\n\x08node_qps\x18\x04 \x01(\x01"A\n+ImageObjectDetectionModelDeploymentMetadata\x12\x12\n\nnode_count\x18\x01 \x01(\x03\x42\x90\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\nImageProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_IMAGECLASSIFICATIONDATASETMETADATA = _descriptor.Descriptor(
    name="ImageClassificationDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.ImageClassificationDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="classification_type",
            full_name="google.cloud.automl.v1beta1.ImageClassificationDatasetMetadata.classification_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=197,
    serialized_end=311,
)


_IMAGEOBJECTDETECTIONDATASETMETADATA = _descriptor.Descriptor(
    name="ImageObjectDetectionDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.ImageObjectDetectionDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=313,
    serialized_end=350,
)


_IMAGECLASSIFICATIONMODELMETADATA = _descriptor.Descriptor(
    name="ImageClassificationModelMetadata",
    full_name="google.cloud.automl.v1beta1.ImageClassificationModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="base_model_id",
            full_name="google.cloud.automl.v1beta1.ImageClassificationModelMetadata.base_model_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="train_budget",
            full_name="google.cloud.automl.v1beta1.ImageClassificationModelMetadata.train_budget",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="train_cost",
            full_name="google.cloud.automl.v1beta1.ImageClassificationModelMetadata.train_cost",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="stop_reason",
            full_name="google.cloud.automl.v1beta1.ImageClassificationModelMetadata.stop_reason",
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="model_type",
            full_name="google.cloud.automl.v1beta1.ImageClassificationModelMetadata.model_type",
            index=4,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=353,
    serialized_end=493,
)


_IMAGEOBJECTDETECTIONMODELMETADATA = _descriptor.Descriptor(
    name="ImageObjectDetectionModelMetadata",
    full_name="google.cloud.automl.v1beta1.ImageObjectDetectionModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="model_type",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionModelMetadata.model_type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="node_count",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionModelMetadata.node_count",
            index=1,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="node_qps",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionModelMetadata.node_qps",
            index=2,
            number=4,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=495,
    serialized_end=588,
)


_IMAGEOBJECTDETECTIONMODELDEPLOYMENTMETADATA = _descriptor.Descriptor(
    name="ImageObjectDetectionModelDeploymentMetadata",
    full_name="google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="node_count",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadata.node_count",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=590,
    serialized_end=655,
)

_IMAGECLASSIFICATIONDATASETMETADATA.fields_by_name[
    "classification_type"
].enum_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2._CLASSIFICATIONTYPE
)
DESCRIPTOR.message_types_by_name[
    "ImageClassificationDatasetMetadata"
] = _IMAGECLASSIFICATIONDATASETMETADATA
DESCRIPTOR.message_types_by_name[
    "ImageObjectDetectionDatasetMetadata"
] = _IMAGEOBJECTDETECTIONDATASETMETADATA
DESCRIPTOR.message_types_by_name[
    "ImageClassificationModelMetadata"
] = _IMAGECLASSIFICATIONMODELMETADATA
DESCRIPTOR.message_types_by_name[
    "ImageObjectDetectionModelMetadata"
] = _IMAGEOBJECTDETECTIONMODELMETADATA
DESCRIPTOR.message_types_by_name[
    "ImageObjectDetectionModelDeploymentMetadata"
] = _IMAGEOBJECTDETECTIONMODELDEPLOYMENTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImageClassificationDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "ImageClassificationDatasetMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGECLASSIFICATIONDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.image_pb2",
        __doc__="""Dataset metadata that is specific to image classification.
  
  
  Attributes:
      classification_type:
          Required. Type of the classification problem.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageClassificationDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(ImageClassificationDatasetMetadata)

ImageObjectDetectionDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "ImageObjectDetectionDatasetMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGEOBJECTDETECTIONDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.image_pb2",
        __doc__="""Dataset metadata specific to image object detection.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageObjectDetectionDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(ImageObjectDetectionDatasetMetadata)

ImageClassificationModelMetadata = _reflection.GeneratedProtocolMessageType(
    "ImageClassificationModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGECLASSIFICATIONMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.image_pb2",
        __doc__="""Model metadata for image classification.
  
  
  Attributes:
      base_model_id:
          Optional. The ID of the ``base`` model. If it is specified,
          the new model will be created based on the ``base`` model.
          Otherwise, the new model will be created from scratch. The
          ``base`` model must be in the same ``project`` and
          ``location`` as the new model to create, and have the same
          ``model_type``.
      train_budget:
          Required. The train budget of creating this model, expressed
          in hours. The actual ``train_cost`` will be equal or less than
          this value.
      train_cost:
          Output only. The actual train cost of creating this model,
          expressed in hours. If this model is created from a ``base``
          model, the train cost used to create the ``base`` model are
          not included.
      stop_reason:
          Output only. The reason that this create model operation
          stopped, e.g. ``BUDGET_REACHED``, ``MODEL_CONVERGED``.
      model_type:
          Optional. Type of the model. The available values are: \*
          ``cloud`` - Model to be used via prediction calls to AutoML
          API. This is the default value. \* ``mobile-low-latency-1`` -
          A model that, in addition to providing prediction via AutoML
          API, can also be exported (see [AutoMl.ExportModel][google.clo
          ud.automl.v1beta1.AutoMl.ExportModel]) and used on a mobile or
          edge device with TensorFlow afterwards. Expected to have low
          latency, but may have lower prediction quality than other
          models. \* ``mobile-versatile-1`` - A model that, in addition
          to providing prediction via AutoML API, can also be exported
          (see [AutoMl.ExportModel][google.cloud.automl.v1beta1.AutoMl.E
          xportModel]) and used on a mobile or edge device with
          TensorFlow afterwards. \* ``mobile-high-accuracy-1`` - A model
          that, in addition to providing prediction via AutoML API, can
          also be exported (see [AutoMl.ExportModel][google.cloud.automl
          .v1beta1.AutoMl.ExportModel]) and used on a mobile or edge
          device with TensorFlow afterwards. Expected to have a higher
          latency, but should also have a higher prediction quality than
          other models. \* ``mobile-core-ml-low-latency-1`` - A model
          that, in addition to providing prediction via AutoML API, can
          also be exported (see [AutoMl.ExportModel][google.cloud.automl
          .v1beta1.AutoMl.ExportModel]) and used on a mobile device with
          Core ML afterwards. Expected to have low latency, but may have
          lower prediction quality than other models. \* ``mobile-core-
          ml-versatile-1`` - A model that, in addition to providing
          prediction via AutoML API, can also be exported (see [AutoMl.E
          xportModel][google.cloud.automl.v1beta1.AutoMl.ExportModel])
          and used on a mobile device with Core ML afterwards. \*
          ``mobile-core-ml-high-accuracy-1`` - A model that, in addition
          to providing prediction via AutoML API, can also be exported
          (see [AutoMl.ExportModel][google.cloud.automl.v1beta1.AutoMl.E
          xportModel]) and used on a mobile device with Core ML
          afterwards. Expected to have a higher latency, but should also
          have a higher prediction quality than other models.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageClassificationModelMetadata)
    ),
)
_sym_db.RegisterMessage(ImageClassificationModelMetadata)

ImageObjectDetectionModelMetadata = _reflection.GeneratedProtocolMessageType(
    "ImageObjectDetectionModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGEOBJECTDETECTIONMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.image_pb2",
        __doc__="""Model metadata specific to image object detection.
  
  
  Attributes:
      model_type:
          Optional. Type of the model. The available values are: \*
          ``cloud-high-accuracy-1`` - (default) A model to be used via
          prediction calls to AutoML API. Expected to have a higher
          latency, but should also have a higher prediction quality than
          other models. \* ``cloud-low-latency-1`` - A model to be used
          via prediction calls to AutoML API. Expected to have low
          latency, but may have lower prediction quality than other
          models.
      node_count:
          Output only. The number of nodes this model is deployed on. A
          node is an abstraction of a machine resource, which can handle
          online prediction QPS as given in the qps\_per\_node field.
      node_qps:
          Output only. An approximate number of online prediction QPS
          that can be supported by this model per each node on which it
          is deployed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageObjectDetectionModelMetadata)
    ),
)
_sym_db.RegisterMessage(ImageObjectDetectionModelMetadata)

ImageObjectDetectionModelDeploymentMetadata = _reflection.GeneratedProtocolMessageType(
    "ImageObjectDetectionModelDeploymentMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGEOBJECTDETECTIONMODELDEPLOYMENTMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.image_pb2",
        __doc__="""Model deployment metadata specific to Image Object Detection.
  
  
  Attributes:
      node_count:
          Input only. The number of nodes to deploy the model on. A node
          is an abstraction of a machine resource, which can handle
          online prediction QPS as given in the model's  [qps\_per\_node
          ][google.cloud.automl.v1beta1.ImageObjectDetectionModelMetadat
          a.qps\_per\_node]. Must be between 1 and 100, inclusive on
          both ends.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadata)
    ),
)
_sym_db.RegisterMessage(ImageObjectDetectionModelDeploymentMetadata)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/io.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/io.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n*google/cloud/automl_v1beta1/proto/io.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto"\x92\x02\n\x0bInputConfig\x12<\n\ngcs_source\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1beta1.GcsSourceH\x00\x12\x46\n\x0f\x62igquery_source\x18\x03 \x01(\x0b\x32+.google.cloud.automl.v1beta1.BigQuerySourceH\x00\x12\x44\n\x06params\x18\x02 \x03(\x0b\x32\x34.google.cloud.automl.v1beta1.InputConfig.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source"\xa9\x01\n\x17\x42\x61tchPredictInputConfig\x12<\n\ngcs_source\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1beta1.GcsSourceH\x00\x12\x46\n\x0f\x62igquery_source\x18\x02 \x01(\x0b\x32+.google.cloud.automl.v1beta1.BigQuerySourceH\x00\x42\x08\n\x06source"Q\n\x13\x44ocumentInputConfig\x12:\n\ngcs_source\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1beta1.GcsSource"\xb7\x01\n\x0cOutputConfig\x12\x46\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32+.google.cloud.automl.v1beta1.GcsDestinationH\x00\x12P\n\x14\x62igquery_destination\x18\x02 \x01(\x0b\x32\x30.google.cloud.automl.v1beta1.BigQueryDestinationH\x00\x42\r\n\x0b\x64\x65stination"\xc3\x01\n\x18\x42\x61tchPredictOutputConfig\x12\x46\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32+.google.cloud.automl.v1beta1.GcsDestinationH\x00\x12P\n\x14\x62igquery_destination\x18\x02 \x01(\x0b\x32\x30.google.cloud.automl.v1beta1.BigQueryDestinationH\x00\x42\r\n\x0b\x64\x65stination"\xcf\x02\n\x17ModelExportOutputConfig\x12\x46\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32+.google.cloud.automl.v1beta1.GcsDestinationH\x00\x12\x46\n\x0fgcr_destination\x18\x03 \x01(\x0b\x32+.google.cloud.automl.v1beta1.GcrDestinationH\x00\x12\x14\n\x0cmodel_format\x18\x04 \x01(\t\x12P\n\x06params\x18\x02 \x03(\x0b\x32@.google.cloud.automl.v1beta1.ModelExportOutputConfig.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b\x64\x65stination"\x86\x01\n#ExportEvaluatedExamplesOutputConfig\x12P\n\x14\x62igquery_destination\x18\x02 \x01(\x0b\x32\x30.google.cloud.automl.v1beta1.BigQueryDestinationH\x00\x42\r\n\x0b\x64\x65stination"\x1f\n\tGcsSource\x12\x12\n\ninput_uris\x18\x01 \x03(\t"#\n\x0e\x42igQuerySource\x12\x11\n\tinput_uri\x18\x01 \x01(\t"+\n\x0eGcsDestination\x12\x19\n\x11output_uri_prefix\x18\x01 \x01(\t")\n\x13\x42igQueryDestination\x12\x12\n\noutput_uri\x18\x01 \x01(\t"$\n\x0eGcrDestination\x12\x12\n\noutput_uri\x18\x01 \x01(\tB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_INPUTCONFIG_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1beta1.InputConfig.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.InputConfig.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.InputConfig.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=325,
    serialized_end=370,
)

_INPUTCONFIG = _descriptor.Descriptor(
    name="InputConfig",
    full_name="google.cloud.automl.v1beta1.InputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.automl.v1beta1.InputConfig.gcs_source",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_source",
            full_name="google.cloud.automl.v1beta1.InputConfig.bigquery_source",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1beta1.InputConfig.params",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_INPUTCONFIG_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.automl.v1beta1.InputConfig.source",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=106,
    serialized_end=380,
)


_BATCHPREDICTINPUTCONFIG = _descriptor.Descriptor(
    name="BatchPredictInputConfig",
    full_name="google.cloud.automl.v1beta1.BatchPredictInputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.automl.v1beta1.BatchPredictInputConfig.gcs_source",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_source",
            full_name="google.cloud.automl.v1beta1.BatchPredictInputConfig.bigquery_source",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.automl.v1beta1.BatchPredictInputConfig.source",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=383,
    serialized_end=552,
)


_DOCUMENTINPUTCONFIG = _descriptor.Descriptor(
    name="DocumentInputConfig",
    full_name="google.cloud.automl.v1beta1.DocumentInputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.automl.v1beta1.DocumentInputConfig.gcs_source",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=554,
    serialized_end=635,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
    name="OutputConfig",
    full_name="google.cloud.automl.v1beta1.OutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.automl.v1beta1.OutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_destination",
            full_name="google.cloud.automl.v1beta1.OutputConfig.bigquery_destination",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1beta1.OutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=638,
    serialized_end=821,
)


_BATCHPREDICTOUTPUTCONFIG = _descriptor.Descriptor(
    name="BatchPredictOutputConfig",
    full_name="google.cloud.automl.v1beta1.BatchPredictOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.automl.v1beta1.BatchPredictOutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_destination",
            full_name="google.cloud.automl.v1beta1.BatchPredictOutputConfig.bigquery_destination",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1beta1.BatchPredictOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=824,
    serialized_end=1019,
)


_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=325,
    serialized_end=370,
)

_MODELEXPORTOUTPUTCONFIG = _descriptor.Descriptor(
    name="ModelExportOutputConfig",
    full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="gcr_destination",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.gcr_destination",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="model_format",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.model_format",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.params",
            index=3,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1beta1.ModelExportOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1022,
    serialized_end=1357,
)


_EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG = _descriptor.Descriptor(
    name="ExportEvaluatedExamplesOutputConfig",
    full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="bigquery_destination",
            full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOutputConfig.bigquery_destination",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1360,
    serialized_end=1494,
)


_GCSSOURCE = _descriptor.Descriptor(
    name="GcsSource",
    full_name="google.cloud.automl.v1beta1.GcsSource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="input_uris",
            full_name="google.cloud.automl.v1beta1.GcsSource.input_uris",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1496,
    serialized_end=1527,
)


_BIGQUERYSOURCE = _descriptor.Descriptor(
    name="BigQuerySource",
    full_name="google.cloud.automl.v1beta1.BigQuerySource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="input_uri",
            full_name="google.cloud.automl.v1beta1.BigQuerySource.input_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1529,
    serialized_end=1564,
)


_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.automl.v1beta1.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_uri_prefix",
            full_name="google.cloud.automl.v1beta1.GcsDestination.output_uri_prefix",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1566,
    serialized_end=1609,
)


_BIGQUERYDESTINATION = _descriptor.Descriptor(
    name="BigQueryDestination",
    full_name="google.cloud.automl.v1beta1.BigQueryDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_uri",
            full_name="google.cloud.automl.v1beta1.BigQueryDestination.output_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1611,
    serialized_end=1652,
)


_GCRDESTINATION = _descriptor.Descriptor(
    name="GcrDestination",
    full_name="google.cloud.automl.v1beta1.GcrDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_uri",
            full_name="google.cloud.automl.v1beta1.GcrDestination.output_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1654,
    serialized_end=1690,
)

_INPUTCONFIG_PARAMSENTRY.containing_type = _INPUTCONFIG
_INPUTCONFIG.fields_by_name["gcs_source"].message_type = _GCSSOURCE
_INPUTCONFIG.fields_by_name["bigquery_source"].message_type = _BIGQUERYSOURCE
_INPUTCONFIG.fields_by_name["params"].message_type = _INPUTCONFIG_PARAMSENTRY
_INPUTCONFIG.oneofs_by_name["source"].fields.append(
    _INPUTCONFIG.fields_by_name["gcs_source"]
)
_INPUTCONFIG.fields_by_name[
    "gcs_source"
].containing_oneof = _INPUTCONFIG.oneofs_by_name["source"]
_INPUTCONFIG.oneofs_by_name["source"].fields.append(
    _INPUTCONFIG.fields_by_name["bigquery_source"]
)
_INPUTCONFIG.fields_by_name[
    "bigquery_source"
].containing_oneof = _INPUTCONFIG.oneofs_by_name["source"]
_BATCHPREDICTINPUTCONFIG.fields_by_name["gcs_source"].message_type = _GCSSOURCE
_BATCHPREDICTINPUTCONFIG.fields_by_name[
    "bigquery_source"
].message_type = _BIGQUERYSOURCE
_BATCHPREDICTINPUTCONFIG.oneofs_by_name["source"].fields.append(
    _BATCHPREDICTINPUTCONFIG.fields_by_name["gcs_source"]
)
_BATCHPREDICTINPUTCONFIG.fields_by_name[
    "gcs_source"
].containing_oneof = _BATCHPREDICTINPUTCONFIG.oneofs_by_name["source"]
_BATCHPREDICTINPUTCONFIG.oneofs_by_name["source"].fields.append(
    _BATCHPREDICTINPUTCONFIG.fields_by_name["bigquery_source"]
)
_BATCHPREDICTINPUTCONFIG.fields_by_name[
    "bigquery_source"
].containing_oneof = _BATCHPREDICTINPUTCONFIG.oneofs_by_name["source"]
_DOCUMENTINPUTCONFIG.fields_by_name["gcs_source"].message_type = _GCSSOURCE
_OUTPUTCONFIG.fields_by_name["gcs_destination"].message_type = _GCSDESTINATION
_OUTPUTCONFIG.fields_by_name["bigquery_destination"].message_type = _BIGQUERYDESTINATION
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["bigquery_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "bigquery_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_BATCHPREDICTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].message_type = _GCSDESTINATION
_BATCHPREDICTOUTPUTCONFIG.fields_by_name[
    "bigquery_destination"
].message_type = _BIGQUERYDESTINATION
_BATCHPREDICTOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _BATCHPREDICTOUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_BATCHPREDICTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _BATCHPREDICTOUTPUTCONFIG.oneofs_by_name["destination"]
_BATCHPREDICTOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _BATCHPREDICTOUTPUTCONFIG.fields_by_name["bigquery_destination"]
)
_BATCHPREDICTOUTPUTCONFIG.fields_by_name[
    "bigquery_destination"
].containing_oneof = _BATCHPREDICTOUTPUTCONFIG.oneofs_by_name["destination"]
_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY.containing_type = _MODELEXPORTOUTPUTCONFIG
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].message_type = _GCSDESTINATION
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "gcr_destination"
].message_type = _GCRDESTINATION
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "params"
].message_type = _MODELEXPORTOUTPUTCONFIG_PARAMSENTRY
_MODELEXPORTOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _MODELEXPORTOUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _MODELEXPORTOUTPUTCONFIG.oneofs_by_name["destination"]
_MODELEXPORTOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _MODELEXPORTOUTPUTCONFIG.fields_by_name["gcr_destination"]
)
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "gcr_destination"
].containing_oneof = _MODELEXPORTOUTPUTCONFIG.oneofs_by_name["destination"]
_EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG.fields_by_name[
    "bigquery_destination"
].message_type = _BIGQUERYDESTINATION
_EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG.fields_by_name["bigquery_destination"]
)
_EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG.fields_by_name[
    "bigquery_destination"
].containing_oneof = _EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG.oneofs_by_name["destination"]
DESCRIPTOR.message_types_by_name["InputConfig"] = _INPUTCONFIG
DESCRIPTOR.message_types_by_name["BatchPredictInputConfig"] = _BATCHPREDICTINPUTCONFIG
DESCRIPTOR.message_types_by_name["DocumentInputConfig"] = _DOCUMENTINPUTCONFIG
DESCRIPTOR.message_types_by_name["OutputConfig"] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name["BatchPredictOutputConfig"] = _BATCHPREDICTOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["ModelExportOutputConfig"] = _MODELEXPORTOUTPUTCONFIG
DESCRIPTOR.message_types_by_name[
    "ExportEvaluatedExamplesOutputConfig"
] = _EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["GcsSource"] = _GCSSOURCE
DESCRIPTOR.message_types_by_name["BigQuerySource"] = _BIGQUERYSOURCE
DESCRIPTOR.message_types_by_name["GcsDestination"] = _GCSDESTINATION
DESCRIPTOR.message_types_by_name["BigQueryDestination"] = _BIGQUERYDESTINATION
DESCRIPTOR.message_types_by_name["GcrDestination"] = _GCRDESTINATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputConfig = _reflection.GeneratedProtocolMessageType(
    "InputConfig",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_INPUTCONFIG_PARAMSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.io_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.InputConfig.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_INPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Input configuration for ImportData Action.
  
  The format of input depends on dataset\_metadata the Dataset into which
  the import is happening has. As input source the
  [gcs\_source][google.cloud.automl.v1beta1.InputConfig.gcs\_source] is
  expected, unless specified otherwise. If a file with identical content
  (even if it had different GCS\_FILE\_PATH) is mentioned multiple times ,
  then its label, bounding boxes etc. are appended. The same file should
  be always provided with the same ML\_USE and GCS\_FILE\_PATH, if it is
  not then these values are nondeterministically selected from the given
  ones.
  
  The formats are represented in EBNF with commas being literal and with
  non-terminal symbols defined near the end of this comment. The formats
  are:
  
  -  For Image Object Detection: CSV file(s) with each line in format:
     ML\_USE,GCS\_FILE\_PATH,LABEL,BOUNDING\_BOX GCS\_FILE\_PATH leads to
     image of up to 30MB in size. Supported extensions: .JPEG, .GIF, .PNG.
     Each image is assumed to be exhaustively labeled. The minimum allowed
     BOUNDING\_BOX edge length is 0.01, and no more than 500
     BOUNDING\_BOX-es per image are allowed. Three sample rows:
     TRAIN,gs://folder/image1.png,car,0.1,0.1,,,0.3,0.3,,
     TRAIN,gs://folder/image1.png,bike,.7,.6,,,.8,.9,,
     TEST,gs://folder/im2.png,car,0.1,0.1,0.2,0.1,0.2,0.3,0.1,0.3
  
  -  For Video Classification: CSV file(s) with each line in format:
     ML\_USE,GCS\_FILE\_PATH where ML\_USE VALIDATE value should not be
     used. The GCS\_FILE\_PATH should lead to another .csv file which
     describes examples that have given ML\_USE, using the following row
     format: GCS\_FILE\_PATH,LABEL,TIME\_SEGMENT\_START,TIME\_SEGMENT\_END
     Here GCS\_FILE\_PATH leads to a video of up to 50GB in size and up to
     3h duration. Supported extensions: .MOV, .MPEG4, .MP4, .AVI.
     TIME\_SEGMENT\_START and TIME\_SEGMENT\_END must be within the length
     of the video, and end has to be after the start. Any segment of a
     video which has one or more labels on it, is considered a hard
     negative for all other labels. Any segment with no labels on it is
     considered to be unknown. Sample top level CSV file:
     TRAIN,gs://folder/train\_videos.csv TEST,gs://folder/test\_videos.csv
     UNASSIGNED,gs://folder/other\_videos.csv Three sample rows of a CSV
     file for a particular ML\_USE:
     gs://folder/video1.avi,car,120,180.000021
     gs://folder/video1.avi,bike,150,180.000021
     gs://folder/vid2.avi,car,0,60.5
  -  For Text Extraction: CSV file(s) with each line in format:
     ML\_USE,GCS\_FILE\_PATH GCS\_FILE\_PATH leads to a .JSONL (i.e. JSON
     Lines) file which either imports text in-line or as documents. The
     in-line .JSONL file contains, per line, a proto that wraps a
     TextSnippet proto (in json representation) followed by one or more
     AnnotationPayload protos (called annotations), which have
     display\_name and text\_extraction detail populated. Given text is
     expected to be annotated exhaustively, e.g. if you look for animals
     and text contains "dolphin" that is not labeled, then "dolphin" will
     be assumed to not be an animal. Any given text snippet content must
     have 30,000 characters or less, and also be UTF-8 NFC encoded (ASCII
     already is). The document .JSONL file contains, per line, a proto
     that wraps a Document proto with input\_config set. Only PDF
     documents are supported now, and each document may be up to 2MB
     large. Currently annotations on documents cannot be specified at
     import. Any given .JSONL file must be 100MB or smaller.

  -  For Tables: Either
     [gcs\_source][google.cloud.automl.v1beta1.InputConfig.gcs\_source] or
  
  [bigquery\_source][google.cloud.automl.v1beta1.InputConfig.bigquery\_source]
  can be used. All inputs will be concatenated into a single
  
  [primary\_table][google.cloud.automl.v1beta1.TablesDatasetMetadata.primary\_table\_name]
  For gcs\_source: CSV file(s), where first file must have a header
  containing unique column names, other files may have such header line
  too, and all other lines contain values for the header columns. Each
  line must have 1,000,000 or fewer characters. First three sample rows of
  a CSV file: "Id","First Name","Last Name","Dob","Addresses"
  
  "1","John","Doe","1968-01-22","[{"status":"current","address":"123\_First\_Avenue","city":"Seattle","state":"WA","zip":"11111","numberOfYears":"1"},{"status":"previous","address":"456\_Main\_Street","city":"Portland","state":"OR","zip":"22222","numberOfYears":"5"}]"
  
  "2","Jane","Doe","1980-10-16","[{"status":"current","address":"789\_Any\_Avenue","city":"Albany","state":"NY","zip":"33333","numberOfYears":"2"},{"status":"previous","address":"321\_Main\_Street","city":"Hoboken","state":"NJ","zip":"44444","numberOfYears":"3"}]}
  For bigquery\_source: An URI of a BigQuery table. An imported table must
  have between 2 and 1,000 columns, inclusive, and between 1,000 and
  10,000,000 rows, inclusive.
  
  -  For Text Sentiment: CSV file(s) with each line in format:
     ML\_USE,TEXT\_SNIPPET,SENTIMENT TEXT\_SNIPPET must have up to 500
     characters. Three sample rows: TRAIN,"@freewrytin God is way too good
     for Claritin",2 TRAIN,"I need Claritin so bad",3 TEST,"Thank god for
     Claritin.",4
  
  Definitions: ML\_USE = "TRAIN" \| "VALIDATE" \| "TEST" \| "UNASSIGNED"
  Describes how the given example (file) should be used for model
  training. "UNASSIGNED" can be used when user has no preference.
  GCS\_FILE\_PATH = A path to file on GCS, e.g. "gs://folder/image1.png".
  LABEL = A display name of an object on an image, video etc., e.g. "dog".
  Must be up to 32 characters long and can consist only of ASCII Latin
  letters A-Z and a-z, underscores(\_), and ASCII digits 0-9. For each
  label an AnnotationSpec is created which display\_name becomes the
  label; AnnotationSpecs are given back in predictions. INSTANCE\_ID = A
  positive integer that identifies a specific instance of a labeled entity
  on an example. Used e.g. to track two cars on a video while being able
  to tell apart which one is which. BOUNDING\_BOX =
  VERTEX,VERTEX,VERTEX,VERTEX \| VERTEX,,,VERTEX,, A rectangle parallel to
  the frame of the example (image, video). If 4 vertices are given they
  are connected by edges in the order provided, if 2 are given they are
  recognized as diagonally opposite vertices of the rectangle. VERTEX =
  COORDINATE,COORDINATE First coordinate is horizontal (x), the second is
  vertical (y). COORDINATE = A float in 0 to 1 range, relative to total
  length of image or video in given dimension. For fractions the leading
  non-decimal 0 can be omitted (i.e. 0.3 = .3). Point 0,0 is in top left.
  TIME\_SEGMENT\_START = TIME\_OFFSET Expresses a beginning, inclusive, of
  a time segment within an example that has a time dimension (e.g. video).
  TIME\_SEGMENT\_END = TIME\_OFFSET Expresses an end, exclusive, of a time
  segment within an example that has a time dimension (e.g. video).
  TIME\_OFFSET = A number of seconds as measured from the start of an
  example (e.g. video). Fractions are allowed, up to a microsecond
  precision. "inf" is allowed, and it means the end of the example.
  TEXT\_SNIPPET = A content of a text snippet, UTF-8 encoded. SENTIMENT =
  An integer between 0 and
  Dataset.text\_sentiment\_dataset\_metadata.sentiment\_max (inclusive).
  Describes the ordinal of the sentiment - higher value means a more
  positive sentiment. All the values are completely relative, i.e. neither
  0 needs to mean a negative or neutral sentiment nor sentiment\_max needs
  to mean a positive one - it is just required that 0 is the least
  positive sentiment in the data, and sentiment\_max is the most positive
  one. The SENTIMENT shouldn't be confused with "score" or "magnitude"
  from the previous Natural Language Sentiment Analysis API. All SENTIMENT
  values between 0 and sentiment\_max must be represented in the imported
  data. On prediction the same 0 to sentiment\_max range will be used. The
  difference between neighboring sentiment values needs not to be uniform,
  e.g. 1 and 2 may be similar whereas the difference between 2 and 3 may
  be huge.
  
  Errors: If any of the provided CSV files can't be parsed or if more than
  certain percent of CSV rows cannot be processed then the operation fails
  and nothing is imported. Regardless of overall success or failure the
  per-row failures, up to a certain count cap, will be listed in
  Operation.metadata.partial\_failures.
  
  
  Attributes:
      source:
          Required. The source of the input.
      gcs_source:
          The Google Cloud Storage location for the input content.
      bigquery_source:
          The BigQuery location for the input content.
      params:
          Additional domain-specific parameters describing the semantic
          of the imported data, any string must be up to 25000
          characters long.  -  For Tables: ``schema_inference_version``
          - (integer) Required. The    version of the algorithm that
          should be used for the initial    inference of the schema
          (columns' DataTypes) of the table the data is    being
          imported into. Allowed values: "1".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.InputConfig)
    ),
)
_sym_db.RegisterMessage(InputConfig)
_sym_db.RegisterMessage(InputConfig.ParamsEntry)

BatchPredictInputConfig = _reflection.GeneratedProtocolMessageType(
    "BatchPredictInputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHPREDICTINPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Input configuration for BatchPredict Action.
  
  The format of input depends on the ML problem of the model used for
  prediction. As input source the
  [gcs\_source][google.cloud.automl.v1beta1.InputConfig.gcs\_source] is
  expected, unless specified otherwise.
  
  The formats are represented in EBNF with commas being literal and with
  non-terminal symbols defined near the end of this comment. The formats
  are:
  
  -  For Video Classification: CSV file(s) with each line in format:
     GCS\_FILE\_PATH,TIME\_SEGMENT\_START,TIME\_SEGMENT\_END
     GCS\_FILE\_PATH leads to video of up to 50GB in size and up to 3h
     duration. Supported extensions: .MOV, .MPEG4, .MP4, .AVI.
     TIME\_SEGMENT\_START and TIME\_SEGMENT\_END must be within the length
     of the video, and end has to be after the start. Three sample rows:
     gs://folder/video1.mp4,10,40 gs://folder/video1.mp4,20,60
     gs://folder/vid2.mov,0,inf
  
  -  For Text Extraction .JSONL (i.e. JSON Lines) file(s) which either
     provide text in-line or as documents (for a single BatchPredict call
     only one of the these formats may be used). The in-line .JSONL
     file(s) contain per line a proto that wraps a temporary user-assigned
     TextSnippet ID (string up to 2000 characters long) called "id"
     followed by a TextSnippet proto (in json representation). Any given
     text snippet content must have 30,000 characters or less, and also be
     UTF-8 NFC encoded (ASCII already is). The IDs provided should be
     unique. The document .JSONL file(s) contain, per line, a proto that
     wraps a Document proto with input\_config set. Only PDF documents are
     supported now, and each document must be up to 2MB large. Any given
     .JSONL file must be 100MB or smaller, and no more than 20 files may
     be given.
  
  -  For Tables: Either
     [gcs\_source][google.cloud.automl.v1beta1.InputConfig.gcs\_source] or
  
  [bigquery\_source][google.cloud.automl.v1beta1.InputConfig.bigquery\_source].
  For gcs\_source: CSV file(s), where first file must have a header
  containing column names, other files may have such header line too, and
  all other lines contain values for the header columns. The column names
  must be exactly same (order may differ) as the model's
  
  [input\_feature\_column\_specs'][google.cloud.automl.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
  [display\_names][google.cloud.automl.v1beta1.display\_name], with values
  compatible with these column specs data types. Prediction on all the
  rows, i.e. the CSV lines, will be attempted. Each line must have
  1,000,000 or fewer characters. First three sample rows of a CSV file:
  "First Name","Last Name","Dob","Addresses"
  
  "John","Doe","1968-01-22","[{"status":"current","address":"123\_First\_Avenue","city":"Seattle","state":"WA","zip":"11111","numberOfYears":"1"},{"status":"previous","address":"456\_Main\_Street","city":"Portland","state":"OR","zip":"22222","numberOfYears":"5"}]"
  
  "Jane","Doe","1980-10-16","[{"status":"current","address":"789\_Any\_Avenue","city":"Albany","state":"NY","zip":"33333","numberOfYears":"2"},{"status":"previous","address":"321\_Main\_Street","city":"Hoboken","state":"NJ","zip":"44444","numberOfYears":"3"}]}
  For bigquery\_source: An URI of a BigQuery table. The table's columns
  must be exactly same (order may differ) as all model's
  
  [input\_feature\_column\_specs'][google.cloud.automl.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
  [display\_names][google.cloud.automl.v1beta1.display\_name], with data
  compatible with these colum specs data types. Prediction on all the rows
  of the table will be attempted.
  
  Definitions: GCS\_FILE\_PATH = A path to file on GCS, e.g.
  "gs://folder/video.avi". TIME\_SEGMENT\_START = TIME\_OFFSET Expresses a
  beginning, inclusive, of a time segment within an example that has a
  time dimension (e.g. video). TIME\_SEGMENT\_END = TIME\_OFFSET Expresses
  an end, exclusive, of a time segment within an example that has a time
  dimension (e.g. video). TIME\_OFFSET = A number of seconds as measured
  from the start of an example (e.g. video). Fractions are allowed, up to
  a microsecond precision. "inf" is allowed and it means the end of the
  example.
  
  Errors: If any of the provided CSV files can't be parsed or if more than
  certain percent of CSV rows cannot be processed then the operation fails
  and prediction does not happen. Regardless of overall success or failure
  the per-row failures, up to a certain count cap, will be listed in
  Operation.metadata.partial\_failures.
  
  
  Attributes:
      source:
          Required. The source of the input.
      gcs_source:
          The Google Cloud Storage location for the input content.
      bigquery_source:
          The BigQuery location for the input content.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictInputConfig)
    ),
)
_sym_db.RegisterMessage(BatchPredictInputConfig)

DocumentInputConfig = _reflection.GeneratedProtocolMessageType(
    "DocumentInputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DOCUMENTINPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Input configuration of a
  [Document][google.cloud.automl.v1beta1.Document].
  
  
  Attributes:
      gcs_source:
          The Google Cloud Storage location of the document file. Only a
          single path should be given. Max supported size: 512MB.
          Supported extensions: .PDF.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DocumentInputConfig)
    ),
)
_sym_db.RegisterMessage(DocumentInputConfig)

OutputConfig = _reflection.GeneratedProtocolMessageType(
    "OutputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_OUTPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Output configuration for ExportData.
  
  As destination the
  [gcs\_destination][google.cloud.automl.v1beta1.OutputConfig.gcs\_destination]
  must be set unless specified otherwise for a domain. Only ground truth
  annotations are exported (not approved annotations are not exported).
  
  The outputs correspond to how the data was imported, and may be used as
  input to import data. The output formats are represented as EBNF with
  literal commas and same non-terminal symbols definitions are these in
  import data's [InputConfig][google.cloud.automl.v1beta1.InputConfig]:
  
  -  For Image Object Detection: CSV file(s)
     ``image_object_detection_1.csv``,
     ``image_object_detection_2.csv``,...,\ ``image_object_detection_N.csv``
     with each line in format: ML\_USE,GCS\_FILE\_PATH,LABEL,BOUNDING\_BOX
     where GCS\_FILE\_PATHs point at the original, source locations of the
     imported images.
  
  -  For Video Classification: CSV file ``video_classification.csv``, with
     each line in format: ML\_USE,GCS\_FILE\_PATH (may have muliple lines
     per a single ML\_USE). Each GCS\_FILE\_PATH leads to another .csv
     file which describes examples that have given ML\_USE, using the
     following row format:
     GCS\_FILE\_PATH,LABEL,TIME\_SEGMENT\_START,TIME\_SEGMENT\_END Here
     GCS\_FILE\_PATHs point at the original, source locations of the
     imported videos.
  -  For Text Extraction: CSV file ``text_extraction.csv``, with each line
     in format: ML\_USE,GCS\_FILE\_PATH GCS\_FILE\_PATH leads to a .JSONL
     (i.e. JSON Lines) file which contains, per line, a proto that wraps a
     TextSnippet proto (in json representation) followed by
     AnnotationPayload protos (called annotations). If initially documents
     had been imported, corresponding OCR-ed representation is returned.
  
  -  For Tables: Output depends on whether the dataset was imported from
     GCS or BigQuery. GCS case:
  
  [gcs\_destination][google.cloud.automl.v1beta1.OutputConfig.gcs\_destination]
  must be set. Exported are CSV file(s) ``tables_1.csv``,
  ``tables_2.csv``,...,\ ``tables_N.csv`` with each having as header line
  the table's column names, and all other lines contain values for the
  header columns. BigQuery case:
  
  [bigquery\_destination][google.cloud.automl.v1beta1.OutputConfig.bigquery\_destination]
  pointing to a BigQuery project must be set. In the given project a new
  dataset will be created with name
  
  ``export_data_<automl-dataset-display-name>_<timestamp-of-export-call>``
  where will be made BigQuery-dataset-name compatible (e.g. most special
  characters will become underscores), and timestamp will be in
  YYYY\_MM\_DDThh\_mm\_ss\_sssZ "based on ISO-8601" format. In that
  dataset a new table called ``primary_table`` will be created, and filled
  with precisely the same data as this obtained on import.
  
  
  Attributes:
      destination:
          Required. The destination of the output.
      gcs_destination:
          The Google Cloud Storage location where the output is to be
          written to. For Image Object Detection, Text Extraction, Video
          Classification and Tables, in the given directory a new
          directory will be created with name: export\_data-- where
          timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. All
          export output will be written into that directory.
      bigquery_destination:
          The BigQuery location where the output is to be written to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.OutputConfig)
    ),
)
_sym_db.RegisterMessage(OutputConfig)

BatchPredictOutputConfig = _reflection.GeneratedProtocolMessageType(
    "BatchPredictOutputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHPREDICTOUTPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Output configuration for BatchPredict Action.
  
  As destination the
  
  [gcs\_destination][google.cloud.automl.v1beta1.BatchPredictOutputConfig.gcs\_destination]
  must be set unless specified otherwise for a domain. If gcs\_destination
  is set then in the given directory a new directory will be created. Its
  name will be "prediction--", where timestamp is in
  YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. The contents of it depend on
  the ML problem the predictions are made for.
  
  -  For Video Classification: In the created directory a
     video\_classification.csv file, and a .JSON file per each video
     classification requested in the input (i.e. each line in given
     CSV(s)), will be created.
  
     ::
  
         The format of video_classification.csv is:
  
  GCS\_FILE\_PATH,TIME\_SEGMENT\_START,TIME\_SEGMENT\_END,JSON\_FILE\_NAME,STATUS
  where: GCS\_FILE\_PATH,TIME\_SEGMENT\_START,TIME\_SEGMENT\_END = matches
  1 to 1 the prediction input lines (i.e. video\_classification.csv has
  precisely the same number of lines as the prediction input had.)
  JSON\_FILE\_NAME = Name of .JSON file in the output directory, which
  contains prediction responses for the video time segment. STATUS = "OK"
  if prediction completed successfully, or an error code and,or message
  otherwise. If STATUS is not "OK" then the .JSON file for that line may
  not exist or be empty.
  
  ::
  
          Each .JSON file, assuming STATUS is "OK", will contain a list of
          AnnotationPayload protos in JSON format, which are the predictions
          for the video time segment the file is assigned to in the
          video_classification.csv. All AnnotationPayload protos will have
          video_classification field set, and will be sorted by
          video_classification.type field (note that the returned types are
          governed by `classifaction_types` parameter in
          [PredictService.BatchPredictRequest.params][]).
  
  -  For Text Extraction: In the created directory files
     ``text_extraction_1.jsonl``,
     ``text_extraction_2.jsonl``,...,\ ``text_extraction_N.jsonl`` will be
     created, where N may be 1, and depends on the total number of inputs
     and annotations found. The contents of these .JSONL file(s) depend on
     whether the input used inline text, or documents. If input was
     inline, then each .JSONL file will contain, per line, a JSON
     representation of a proto that wraps given in request text snippet's
     "id" : "" followed by a list of zero or more AnnotationPayload protos
     (called annotations), which have text\_extraction detail populated. A
     single text snippet will be listed only once with all its
     annotations, and its annotations will never be split across files. If
     input used documents, then each .JSONL file will contain, per line, a
     JSON representation of a proto that wraps given in request document
     proto, followed by its OCR-ed representation in the form of a text
     snippet, finally followed by a list of zero or more AnnotationPayload
     protos (called annotations), which have text\_extraction detail
     populated and refer, via their indices, to the OCR-ed text snippet. A
     single document (and its text snippet) will be listed only once with
     all its annotations, and its annotations will never be split across
     files. If prediction for any text snippet failed (partially or
     completely), then additional ``errors_1.jsonl``,
     ``errors_2.jsonl``,..., ``errors_N.jsonl`` files will be created (N
     depends on total number of failed predictions). These files will have
     a JSON representation of a proto that wraps either the "id" : "" (in
     case of inline) or the document proto (in case of document) but here
     followed by exactly one
  
  ```google.rpc.Status`` <https:%20//github.com/googleapis/googleapis/blob/master/google/rpc/status.proto>`__
  containing only ``code`` and ``message``.
  
  -  For Tables: Output depends on whether
  
  [gcs\_destination][google.cloud.automl.v1beta1.BatchPredictOutputConfig.gcs\_destination]
  or
  
  [bigquery\_destination][google.cloud.automl.v1beta1.BatchPredictOutputConfig.bigquery\_destination]
  is set (either is allowed). GCS case: In the created directory files
  ``tables_1.csv``, ``tables_2.csv``,..., ``tables_N.csv`` will be
  created, where N may be 1, and depends on the total number of the
  successfully predicted rows. For the classification models: Each .csv
  file will contain a header, listing all model's
  
  [input\_feature\_column\_specs'][google.cloud.automl.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
  
  [display\_names][google.cloud.automl.v1beta1.ColumnSpec.display\_name]
  followed by M target column names in the format of
  
  "<[target\_column\_specs][google.cloud.automl.v1beta1.TablesModelMetadata.target\_column\_spec]
  
  [display\_name][google.cloud.automl.v1beta1.ColumnSpec.display\_name]>\_\_score"
  where M is the number of distinct target values, i.e. number of distinct
  values in the target column of the table used to train the model.
  Subsequent lines will contain the respective values of successfully
  predicted rows, with the last, i.e. the target, columns having the
  corresponding prediction
  [scores][google.cloud.automl.v1beta1.TablesAnnotation.score]. For the
  regression models: Each .csv file will contain a header, listing all
  model's
  
  [input\_feature\_column\_specs][google.cloud.automl.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
  [display\_names][google.cloud.automl.v1beta1.display\_name] followed by
  the target column with name equal to
  
  [target\_column\_specs'][google.cloud.automl.v1beta1.TablesModelMetadata.target\_column\_spec]
  
  [display\_name][google.cloud.automl.v1beta1.ColumnSpec.display\_name].
  Subsequent lines will contain the respective values of successfully
  predicted rows, with the last, i.e. the target, column having the
  predicted target value. If prediction for any rows failed, then an
  additional ``errors_1.csv``, ``errors_2.csv``,..., ``errors_N.csv`` will
  be created (N depends on total number of failed rows). These files will
  have analogous format as ``tables_*.csv``, but always with a single
  target column having
  
  ```google.rpc.Status`` <https:%20//github.com/googleapis/googleapis/blob/master/google/rpc/status.proto>`__
  represented as a JSON string, and containing only ``code`` and
  ``message``. BigQuery case:
  
  [bigquery\_destination][google.cloud.automl.v1beta1.OutputConfig.bigquery\_destination]
  pointing to a BigQuery project must be set. In the given project a new
  dataset will be created with name
  ``prediction_<model-display-name>_<timestamp-of-prediction-call>`` where
  will be made BigQuery-dataset-name compatible (e.g. most special
  characters will become underscores), and timestamp will be in
  YYYY\_MM\_DDThh\_mm\_ss\_sssZ "based on ISO-8601" format. In the dataset
  two tables will be created, ``predictions``, and ``errors``. The
  ``predictions`` table's column names will be the
  
  [input\_feature\_column\_specs'][google.cloud.automl.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
  
  [display\_names][google.cloud.automl.v1beta1.ColumnSpec.display\_name]
  followed by model's
  
  [target\_column\_specs'][google.cloud.automl.v1beta1.TablesModelMetadata.target\_column\_spec]
  
  [display\_name][google.cloud.automl.v1beta1.ColumnSpec.display\_name].
  The input feature columns will contain the respective values of
  successfully predicted rows, with the target column having an ARRAY of
  
  [AnnotationPayloads][google.cloud.automl.v1beta1.AnnotationPayload],
  represented as STRUCT-s, containing
  [TablesAnnotation][google.cloud.automl.v1beta1.TablesAnnotation]. The
  ``errors`` table contains rows for which the prediction has failed, it
  has analogous input feature and target columns, but here the target
  column as a value has
  
  ```google.rpc.Status`` <https:%20//github.com/googleapis/googleapis/blob/master/google/rpc/status.proto>`__
  represented as a STRUCT, and containing only ``code`` and ``message``.
  
  
  Attributes:
      destination:
          Required. The destination of the output.
      gcs_destination:
          The Google Cloud Storage location of the directory where the
          output is to be written to.
      bigquery_destination:
          The BigQuery location where the output is to be written to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictOutputConfig)
    ),
)
_sym_db.RegisterMessage(BatchPredictOutputConfig)

ModelExportOutputConfig = _reflection.GeneratedProtocolMessageType(
    "ModelExportOutputConfig",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.io_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ModelExportOutputConfig.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_MODELEXPORTOUTPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Output configuration for ModelExport Action.
  
  
  Attributes:
      destination:
          Required. The destination of the output.
      gcs_destination:
          The Google Cloud Storage location where the model is to be
          written to. This location may only be set for the following
          model formats: "tflite", "edgetpu\_tflite", "core\_ml",
          "docker".  Under the directory given as the destination a new
          one with name "model-export--", where timestamp is in YYYY-MM-
          DDThh:mm:ss.sssZ ISO-8601 format, will be created. Inside the
          model and any of its supporting files will be written, as
          described  `here <https://cloud.google.com/vision/automl/docs/
          deploy#deployment_to_devices>`__.
      gcr_destination:
          The GCR location where model image is to be pushed to. This
          location may only be set for the following model formats:
          "docker".  The model image will be created under the given
          URI.
      model_format:
          The format in which the model must be exported. The available,
          and default, formats depend on the problem and model type (if
          given problem and type combination doesn't have a format
          listed, it means its models are not exportable):  -  For Image
          Classification mobile-low-latency-1, mobile-versatile-1,
          mobile-high-accuracy-1: "tflite" (default), "edgetpu\_tflite",
          "tf\_saved\_model", "docker".  -  For Image Classification
          mobile-core-ml-low-latency-1,    mobile-core-ml-versatile-1,
          mobile-core-ml-high-accuracy-1:    "core\_ml" (default).
          Formats description:  -  tflite - Used for Android mobile
          devices. -  edgetpu\_tflite - Used for `Edge    TPU
          <https://cloud.google.com/edge-tpu/>`__ devices. -
          tf\_saved\_model - A tensorflow model in SavedModel format. -
          docker - Used for Docker containers. Use the params field to
          customize the container. The container is verified to work
          correctly    on ubuntu 16.04 operating system. -  core\_ml -
          Used for iOS mobile devices.
      params:
          Additional model-type and format specific parameters
          describing the requirements for the to be exported model
          files, any string must be up to 25000 characters long.  -  For
          ``docker`` format: ``cpu_architecture`` - (string) "x86\_64"
          (default). ``gpu_architecture`` - (string) "none" (default),
          "nvidia".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ModelExportOutputConfig)
    ),
)
_sym_db.RegisterMessage(ModelExportOutputConfig)
_sym_db.RegisterMessage(ModelExportOutputConfig.ParamsEntry)

ExportEvaluatedExamplesOutputConfig = _reflection.GeneratedProtocolMessageType(
    "ExportEvaluatedExamplesOutputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""Output configuration for ExportEvaluatedExamples Action. Note that this
  call is available only for 30 days since the moment the model was
  evaluated. The output depends on the domain, as follows (note that only
  examples from the TEST set are exported):
  
  -  For Tables:
  
  [bigquery\_destination][google.cloud.automl.v1beta1.OutputConfig.bigquery\_destination]
  pointing to a BigQuery project must be set. In the given project a new
  dataset will be created with name
  
  ``export_evaluated_examples_<model-display-name>_<timestamp-of-export-call>``
  where will be made BigQuery-dataset-name compatible (e.g. most special
  characters will become underscores), and timestamp will be in
  YYYY\_MM\_DDThh\_mm\_ss\_sssZ "based on ISO-8601" format. In the dataset
  an ``evaluated_examples`` table will be created. It will have all the
  same columns as the [primary
  
  table][google.cloud.automl.v1beta1.TablesDatasetMetadata.primary\_table\_spec\_id]
  of the [dataset][google.cloud.automl.v1beta1.Model.dataset\_id] from
  which the model was created, as they were at the moment of model's
  evaluation (this includes the target column with its ground truth),
  followed by a column called "predicted\_". That last column will contain
  the model's prediction result for each respective row, given as ARRAY of
  [AnnotationPayloads][google.cloud.automl.v1beta1.AnnotationPayload],
  represented as STRUCT-s, containing
  [TablesAnnotation][google.cloud.automl.v1beta1.TablesAnnotation].
  
  
  Attributes:
      destination:
          Required. The destination of the output.
      bigquery_destination:
          The BigQuery location where the output is to be written to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportEvaluatedExamplesOutputConfig)
    ),
)
_sym_db.RegisterMessage(ExportEvaluatedExamplesOutputConfig)

GcsSource = _reflection.GeneratedProtocolMessageType(
    "GcsSource",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GCSSOURCE,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""The Google Cloud Storage location for the input content.
  
  
  Attributes:
      input_uris:
          Required. Google Cloud Storage URIs to input files, up to 2000
          characters long. Accepted forms: \* Full object path, e.g.
          gs://bucket/directory/object.csv
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GcsSource)
    ),
)
_sym_db.RegisterMessage(GcsSource)

BigQuerySource = _reflection.GeneratedProtocolMessageType(
    "BigQuerySource",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BIGQUERYSOURCE,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""The BigQuery location for the input content.
  
  
  Attributes:
      input_uri:
          Required. BigQuery URI to a table, up to 2000 characters long.
          Accepted forms: \* BigQuery path e.g.
          bq://projectId.bqDatasetId.bqTableId
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BigQuerySource)
    ),
)
_sym_db.RegisterMessage(BigQuerySource)

GcsDestination = _reflection.GeneratedProtocolMessageType(
    "GcsDestination",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GCSDESTINATION,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""The Google Cloud Storage location where the output is to be written to.
  
  
  Attributes:
      output_uri_prefix:
          Required. Google Cloud Storage URI to output directory, up to
          2000 characters long. Accepted forms: \* Prefix path:
          gs://bucket/directory The requesting user must have write
          permission to the bucket. The directory is created if it
          doesn't exist.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GcsDestination)
    ),
)
_sym_db.RegisterMessage(GcsDestination)

BigQueryDestination = _reflection.GeneratedProtocolMessageType(
    "BigQueryDestination",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BIGQUERYDESTINATION,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""The BigQuery location for the output content.
  
  
  Attributes:
      output_uri:
          Required. BigQuery URI to a project, up to 2000 characters
          long. Accepted forms: \* BigQuery path e.g. bq://projectId
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BigQueryDestination)
    ),
)
_sym_db.RegisterMessage(BigQueryDestination)

GcrDestination = _reflection.GeneratedProtocolMessageType(
    "GcrDestination",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GCRDESTINATION,
        __module__="google.cloud.automl_v1beta1.proto.io_pb2",
        __doc__="""The GCR location where the image must be pushed to.
  
  
  Attributes:
      output_uri:
          Required. Google Contained Registry URI of the new image, up
          to 2000 characters long. See  https:
          //cloud.google.com/container-registry/do // cs/pushing-and-
          pulling#pushing\_an\_image\_to\_a\_registry Accepted forms: \*
          [HOSTNAME]/[PROJECT-ID]/[IMAGE] \* [HOSTNAME]/[PROJECT-
          ID]/[IMAGE]:[TAG]  The requesting user must have permission to
          push images the project.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GcrDestination)
    ),
)
_sym_db.RegisterMessage(GcrDestination)


DESCRIPTOR._options = None
_INPUTCONFIG_PARAMSENTRY._options = None
_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/classification.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    temporal_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_temporal__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/classification.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\023ClassificationProtoZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n6google/cloud/automl_v1beta1/proto/classification.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x30google/cloud/automl_v1beta1/proto/temporal.proto")\n\x18\x43lassificationAnnotation\x12\r\n\x05score\x18\x01 \x01(\x02"\xc7\x01\n\x1dVideoClassificationAnnotation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12X\n\x19\x63lassification_annotation\x18\x02 \x01(\x0b\x32\x35.google.cloud.automl.v1beta1.ClassificationAnnotation\x12>\n\x0ctime_segment\x18\x03 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TimeSegment"\x93\x07\n\x1f\x43lassificationEvaluationMetrics\x12\x0e\n\x06\x61u_prc\x18\x01 \x01(\x02\x12\x17\n\x0b\x62\x61se_au_prc\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x0e\n\x06\x61u_roc\x18\x06 \x01(\x02\x12\x10\n\x08log_loss\x18\x07 \x01(\x02\x12u\n\x18\x63onfidence_metrics_entry\x18\x03 \x03(\x0b\x32S.google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry\x12\x66\n\x10\x63onfusion_matrix\x18\x04 \x01(\x0b\x32L.google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix\x12\x1a\n\x12\x61nnotation_spec_id\x18\x05 \x03(\t\x1a\xfc\x02\n\x16\x43onfidenceMetricsEntry\x12\x1c\n\x14\x63onfidence_threshold\x18\x01 \x01(\x02\x12\x1a\n\x12position_threshold\x18\x0e \x01(\x05\x12\x0e\n\x06recall\x18\x02 \x01(\x02\x12\x11\n\tprecision\x18\x03 \x01(\x02\x12\x1b\n\x13\x66\x61lse_positive_rate\x18\x08 \x01(\x02\x12\x10\n\x08\x66\x31_score\x18\x04 \x01(\x02\x12\x12\n\nrecall_at1\x18\x05 \x01(\x02\x12\x15\n\rprecision_at1\x18\x06 \x01(\x02\x12\x1f\n\x17\x66\x61lse_positive_rate_at1\x18\t \x01(\x02\x12\x14\n\x0c\x66\x31_score_at1\x18\x07 \x01(\x02\x12\x1b\n\x13true_positive_count\x18\n \x01(\x03\x12\x1c\n\x14\x66\x61lse_positive_count\x18\x0b \x01(\x03\x12\x1c\n\x14\x66\x61lse_negative_count\x18\x0c \x01(\x03\x12\x1b\n\x13true_negative_count\x18\r \x01(\x03\x1a\xaa\x01\n\x0f\x43onfusionMatrix\x12\x1a\n\x12\x61nnotation_spec_id\x18\x01 \x03(\t\x12]\n\x03row\x18\x02 \x03(\x0b\x32P.google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix.Row\x1a\x1c\n\x03Row\x12\x15\n\rexample_count\x18\x01 \x03(\x05*Y\n\x12\x43lassificationType\x12#\n\x1f\x43LASSIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nMULTICLASS\x10\x01\x12\x0e\n\nMULTILABEL\x10\x02\x42\x97\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x13\x43lassificationProtoZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_temporal__pb2.DESCRIPTOR,
    ],
)

_CLASSIFICATIONTYPE = _descriptor.EnumDescriptor(
    name="ClassificationType",
    full_name="google.cloud.automl.v1beta1.ClassificationType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CLASSIFICATION_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="MULTICLASS", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MULTILABEL", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1330,
    serialized_end=1419,
)
_sym_db.RegisterEnumDescriptor(_CLASSIFICATIONTYPE)

ClassificationType = enum_type_wrapper.EnumTypeWrapper(_CLASSIFICATIONTYPE)
CLASSIFICATION_TYPE_UNSPECIFIED = 0
MULTICLASS = 1
MULTILABEL = 2


_CLASSIFICATIONANNOTATION = _descriptor.Descriptor(
    name="ClassificationAnnotation",
    full_name="google.cloud.automl.v1beta1.ClassificationAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="score",
            full_name="google.cloud.automl.v1beta1.ClassificationAnnotation.score",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=167,
    serialized_end=208,
)


_VIDEOCLASSIFICATIONANNOTATION = _descriptor.Descriptor(
    name="VideoClassificationAnnotation",
    full_name="google.cloud.automl.v1beta1.VideoClassificationAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.automl.v1beta1.VideoClassificationAnnotation.type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="classification_annotation",
            full_name="google.cloud.automl.v1beta1.VideoClassificationAnnotation.classification_annotation",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="time_segment",
            full_name="google.cloud.automl.v1beta1.VideoClassificationAnnotation.time_segment",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=211,
    serialized_end=410,
)


_CLASSIFICATIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY = _descriptor.Descriptor(
    name="ConfidenceMetricsEntry",
    full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="confidence_threshold",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.confidence_threshold",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="position_threshold",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.position_threshold",
            index=1,
            number=14,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="recall",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.recall",
            index=2,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="precision",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.precision",
            index=3,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="false_positive_rate",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.false_positive_rate",
            index=4,
            number=8,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="f1_score",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.f1_score",
            index=5,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="recall_at1",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.recall_at1",
            index=6,
            number=5,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="precision_at1",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.precision_at1",
            index=7,
            number=6,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="false_positive_rate_at1",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.false_positive_rate_at1",
            index=8,
            number=9,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="f1_score_at1",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.f1_score_at1",
            index=9,
            number=7,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="true_positive_count",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.true_positive_count",
            index=10,
            number=10,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="false_positive_count",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.false_positive_count",
            index=11,
            number=11,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="false_negative_count",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.false_negative_count",
            index=12,
            number=12,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="true_negative_count",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.true_negative_count",
            index=13,
            number=13,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=775,
    serialized_end=1155,
)

_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX_ROW = _descriptor.Descriptor(
    name="Row",
    full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix.Row",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="example_count",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix.Row.example_count",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1300,
    serialized_end=1328,
)

_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX = _descriptor.Descriptor(
    name="ConfusionMatrix",
    full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="annotation_spec_id",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix.annotation_spec_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="row",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix.row",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX_ROW],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1158,
    serialized_end=1328,
)

_CLASSIFICATIONEVALUATIONMETRICS = _descriptor.Descriptor(
    name="ClassificationEvaluationMetrics",
    full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="au_prc",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.au_prc",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="base_au_prc",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.base_au_prc",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\030\001"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="au_roc",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.au_roc",
            index=2,
            number=6,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="log_loss",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.log_loss",
            index=3,
            number=7,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="confidence_metrics_entry",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.confidence_metrics_entry",
            index=4,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="confusion_matrix",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.confusion_matrix",
            index=5,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="annotation_spec_id",
            full_name="google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.annotation_spec_id",
            index=6,
            number=5,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[
        _CLASSIFICATIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY,
        _CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=413,
    serialized_end=1328,
)

_VIDEOCLASSIFICATIONANNOTATION.fields_by_name[
    "classification_annotation"
].message_type = _CLASSIFICATIONANNOTATION
_VIDEOCLASSIFICATIONANNOTATION.fields_by_name[
    "time_segment"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_temporal__pb2._TIMESEGMENT
)
_CLASSIFICATIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY.containing_type = (
    _CLASSIFICATIONEVALUATIONMETRICS
)
_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX_ROW.containing_type = (
    _CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX
)
_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX.fields_by_name[
    "row"
].message_type = _CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX_ROW
_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX.containing_type = (
    _CLASSIFICATIONEVALUATIONMETRICS
)
_CLASSIFICATIONEVALUATIONMETRICS.fields_by_name[
    "confidence_metrics_entry"
].message_type = _CLASSIFICATIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY
_CLASSIFICATIONEVALUATIONMETRICS.fields_by_name[
    "confusion_matrix"
].message_type = _CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX
DESCRIPTOR.message_types_by_name["ClassificationAnnotation"] = _CLASSIFICATIONANNOTATION
DESCRIPTOR.message_types_by_name[
    "VideoClassificationAnnotation"
] = _VIDEOCLASSIFICATIONANNOTATION
DESCRIPTOR.message_types_by_name[
    "ClassificationEvaluationMetrics"
] = _CLASSIFICATIONEVALUATIONMETRICS
DESCRIPTOR.enum_types_by_name["ClassificationType"] = _CLASSIFICATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationAnnotation = _reflection.GeneratedProtocolMessageType(
    "ClassificationAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CLASSIFICATIONANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.classification_pb2",
        __doc__="""Contains annotation details specific to classification.
  
  
  Attributes:
      score:
          Output only. A confidence estimate between 0.0 and 1.0. A
          higher value means greater confidence that the annotation is
          positive. If a user approves an annotation as negative or
          positive, the score value remains unchanged. If a user creates
          an annotation, the score is 0 for negative or 1 for positive.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ClassificationAnnotation)
    ),
)
_sym_db.RegisterMessage(ClassificationAnnotation)

VideoClassificationAnnotation = _reflection.GeneratedProtocolMessageType(
    "VideoClassificationAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_VIDEOCLASSIFICATIONANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.classification_pb2",
        __doc__="""Contains annotation details specific to video classification.
  
  
  Attributes:
      type:
          Output only. Expresses the type of video classification.
          Possible values:  -  ``segment`` - Classification done on a
          specified by user time segment    of a video. AnnotationSpec
          is answered to be present in that time    segment, if it is
          present in any part of it. The video ML model    evaluations
          are done only for this type of classification.  -  ``shot``-
          Shot-level classification. AutoML Video Intelligence
          determines the boundaries for each camera shot in the entire
          segment    of the video that user specified in the request
          configuration. AutoML    Video Intelligence then returns
          labels and their confidence scores    for each detected shot,
          along with the start and end time of the    shot. WARNING:
          Model evaluation is not done for this classification    type,
          the quality of it depends on training data, but there are no
          metrics provided to describe that quality.  -  ``1s_interval``
          - AutoML Video Intelligence returns labels and their
          confidence scores for each second of the entire segment of the
          video    that user specified in the request configuration.
          WARNING: Model    evaluation is not done for this
          classification type, the quality of    it depends on training
          data, but there are no metrics provided to    describe that
          quality.
      classification_annotation:
          Output only . The classification details of this annotation.
      time_segment:
          Output only . The time segment of the video to which the
          annotation applies.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.VideoClassificationAnnotation)
    ),
)
_sym_db.RegisterMessage(VideoClassificationAnnotation)

ClassificationEvaluationMetrics = _reflection.GeneratedProtocolMessageType(
    "ClassificationEvaluationMetrics",
    (_message.Message,),
    dict(
        ConfidenceMetricsEntry=_reflection.GeneratedProtocolMessageType(
            "ConfidenceMetricsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_CLASSIFICATIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.classification_pb2",
                __doc__="""Metrics for a single confidence threshold.
    
    
    Attributes:
        confidence_threshold:
            Output only. Metrics are computed with an assumption that the
            model never returns predictions with score lower than this
            value.
        position_threshold:
            Output only. Metrics are computed with an assumption that the
            model always returns at most this many predictions (ordered by
            their score, descendingly), but they all still need to meet
            the confidence\_threshold.
        recall:
            Output only. Recall (True Positive Rate) for the given
            confidence threshold.
        precision:
            Output only. Precision for the given confidence threshold.
        false_positive_rate:
            Output only. False Positive Rate for the given confidence
            threshold.
        f1_score:
            Output only. The harmonic mean of recall and precision.
        recall_at1:
            Output only. The Recall (True Positive Rate) when only
            considering the label that has the highest prediction score
            and not below the confidence threshold for each example.
        precision_at1:
            Output only. The precision when only considering the label
            that has the highest prediction score and not below the
            confidence threshold for each example.
        false_positive_rate_at1:
            Output only. The False Positive Rate when only considering the
            label that has the highest prediction score and not below the
            confidence threshold for each example.
        f1_score_at1:
            Output only. The harmonic mean of [recall\_at1][google.cloud.a
            utoml.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetric
            sEntry.recall\_at1] and [precision\_at1][google.cloud.automl.v
            1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.
            precision\_at1].
        true_positive_count:
            Output only. The number of model created labels that match a
            ground truth label.
        false_positive_count:
            Output only. The number of model created labels that do not
            match a ground truth label.
        false_negative_count:
            Output only. The number of ground truth labels that are not
            matched by a model created label.
        true_negative_count:
            Output only. The number of labels that were not created by the
            model, but if they would, they would not match a ground truth
            label.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry)
            ),
        ),
        ConfusionMatrix=_reflection.GeneratedProtocolMessageType(
            "ConfusionMatrix",
            (_message.Message,),
            dict(
                Row=_reflection.GeneratedProtocolMessageType(
                    "Row",
                    (_message.Message,),
                    dict(
                        DESCRIPTOR=_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX_ROW,
                        __module__="google.cloud.automl_v1beta1.proto.classification_pb2",
                        __doc__="""Output only. A row in the confusion matrix.
      
      
      Attributes:
          example_count:
              Output only. Value of the specific cell in the confusion
              matrix. The number of values each row has (i.e. the length of
              the row) is equal to the length of the annotation\_spec\_id
              field.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix.Row)
                    ),
                ),
                DESCRIPTOR=_CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX,
                __module__="google.cloud.automl_v1beta1.proto.classification_pb2",
                __doc__="""Confusion matrix of the model running the classification.
    
    
    Attributes:
        annotation_spec_id:
            Output only. IDs of the annotation specs used in the confusion
            matrix.
        row:
            Output only. Rows in the confusion matrix. The number of rows
            is equal to the size of ``annotation_spec_id``.
            ``row[i].value[j]`` is the number of examples that have ground
            truth of the ``annotation_spec_id[i]`` and are predicted as
            ``annotation_spec_id[j]`` by the model being evaluated.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix)
            ),
        ),
        DESCRIPTOR=_CLASSIFICATIONEVALUATIONMETRICS,
        __module__="google.cloud.automl_v1beta1.proto.classification_pb2",
        __doc__="""Model evaluation metrics for classification problems. Note: For Video
  Classification this metrics only describe quality of the Video
  Classification predictions of "segment\_classification" type.
  
  
  Attributes:
      au_prc:
          Output only. The Area Under Precision-Recall Curve metric.
          Micro-averaged for the overall evaluation.
      base_au_prc:
          Output only. The Area Under Precision-Recall Curve metric
          based on priors. Micro-averaged for the overall evaluation.
          Deprecated.
      au_roc:
          Output only. The Area Under Receiver Operating Characteristic
          curve metric. Micro-averaged for the overall evaluation.
      log_loss:
          Output only. The Log Loss metric.
      confidence_metrics_entry:
          Output only. Metrics for each confidence\_threshold in
          0.00,0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and
          position\_threshold = INT32\_MAX\_VALUE. Precision-recall
          curve is derived from them. The above metrics may also be
          supplied for additional values of position\_threshold.
      confusion_matrix:
          Output only. Confusion matrix of the evaluation. Only set for
          MULTICLASS classification problems where number of labels is
          no more than 10. Only set for model level evaluation, not for
          evaluation per label.
      annotation_spec_id:
          Output only. The annotation spec ids used for this evaluation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ClassificationEvaluationMetrics)
    ),
)
_sym_db.RegisterMessage(ClassificationEvaluationMetrics)
_sym_db.RegisterMessage(ClassificationEvaluationMetrics.ConfidenceMetricsEntry)
_sym_db.RegisterMessage(ClassificationEvaluationMetrics.ConfusionMatrix)
_sym_db.RegisterMessage(ClassificationEvaluationMetrics.ConfusionMatrix.Row)


DESCRIPTOR._options = None
_CLASSIFICATIONEVALUATIONMETRICS.fields_by_name["base_au_prc"]._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/regression.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/regression.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\017RegressionProtoZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/regression.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto"\x96\x01\n\x1bRegressionEvaluationMetrics\x12\x1f\n\x17root_mean_squared_error\x18\x01 \x01(\x02\x12\x1b\n\x13mean_absolute_error\x18\x02 \x01(\x02\x12&\n\x1emean_absolute_percentage_error\x18\x03 \x01(\x02\x12\x11\n\tr_squared\x18\x04 \x01(\x02\x42\x93\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x0fRegressionProtoZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_REGRESSIONEVALUATIONMETRICS = _descriptor.Descriptor(
    name="RegressionEvaluationMetrics",
    full_name="google.cloud.automl.v1beta1.RegressionEvaluationMetrics",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="root_mean_squared_error",
            full_name="google.cloud.automl.v1beta1.RegressionEvaluationMetrics.root_mean_squared_error",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mean_absolute_error",
            full_name="google.cloud.automl.v1beta1.RegressionEvaluationMetrics.mean_absolute_error",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mean_absolute_percentage_error",
            full_name="google.cloud.automl.v1beta1.RegressionEvaluationMetrics.mean_absolute_percentage_error",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="r_squared",
            full_name="google.cloud.automl.v1beta1.RegressionEvaluationMetrics.r_squared",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=114,
    serialized_end=264,
)

DESCRIPTOR.message_types_by_name[
    "RegressionEvaluationMetrics"
] = _REGRESSIONEVALUATIONMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RegressionEvaluationMetrics = _reflection.GeneratedProtocolMessageType(
    "RegressionEvaluationMetrics",
    (_message.Message,),
    dict(
        DESCRIPTOR=_REGRESSIONEVALUATIONMETRICS,
        __module__="google.cloud.automl_v1beta1.proto.regression_pb2",
        __doc__="""Metrics for regression problems.
  
  
  Attributes:
      root_mean_squared_error:
          Output only. Root Mean Squared Error (RMSE).
      mean_absolute_error:
          Output only. Mean Absolute Error (MAE).
      mean_absolute_percentage_error:
          Output only. Mean absolute percentage error. Only set if all
          ground truth values are are positive.
      r_squared:
          Output only. R squared.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.RegressionEvaluationMetrics)
    ),
)
_sym_db.RegisterMessage(RegressionEvaluationMetrics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
